==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/eventarc_trigger/EventarcTriggerDestinationOutputReference.java <==
package com.hashicorp.cdktf.providers.google.eventarc_trigger;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:41.822Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.eventarcTrigger.EventarcTriggerDestinationOutputReference")
public class EventarcTriggerDestinationOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected EventarcTriggerDestinationOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EventarcTriggerDestinationOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public EventarcTriggerDestinationOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putCloudRunService(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService value) {
        software.amazon.jsii.Kernel.call(this, "putCloudRunService", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putGke(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke value) {
        software.amazon.jsii.Kernel.call(this, "putGke", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCloudFunction() {
        software.amazon.jsii.Kernel.call(this, "resetCloudFunction", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCloudRunService() {
        software.amazon.jsii.Kernel.call(this, "resetCloudRunService", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetGke() {
        software.amazon.jsii.Kernel.call(this, "resetGke", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetWorkflow() {
        software.amazon.jsii.Kernel.call(this, "resetWorkflow", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunServiceOutputReference getCloudRunService() {
        return software.amazon.jsii.Kernel.get(this, "cloudRunService", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunServiceOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGkeOutputReference getGke() {
        return software.amazon.jsii.Kernel.get(this, "gke", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGkeOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getCloudFunctionInput() {
        return software.amazon.jsii.Kernel.get(this, "cloudFunctionInput", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService getCloudRunServiceInput() {
        return software.amazon.jsii.Kernel.get(this, "cloudRunServiceInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke getGkeInput() {
        return software.amazon.jsii.Kernel.get(this, "gkeInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getWorkflowInput() {
        return software.amazon.jsii.Kernel.get(this, "workflowInput", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getCloudFunction() {
        return software.amazon.jsii.Kernel.get(this, "cloudFunction", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setCloudFunction(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.set(this, "cloudFunction", java.util.Objects.requireNonNull(value, "cloudFunction is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getWorkflow() {
        return software.amazon.jsii.Kernel.get(this, "workflow", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setWorkflow(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.set(this, "workflow", java.util.Objects.requireNonNull(value, "workflow is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestination getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestination.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestination value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/eventarc_trigger/EventarcTriggerDestinationOutputReference.java <==
package com.hashicorp.cdktf.providers.google.eventarc_trigger;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:15.890Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.eventarcTrigger.EventarcTriggerDestinationOutputReference")
public class EventarcTriggerDestinationOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected EventarcTriggerDestinationOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EventarcTriggerDestinationOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public EventarcTriggerDestinationOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putCloudRunService(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService value) {
        software.amazon.jsii.Kernel.call(this, "putCloudRunService", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putGke(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke value) {
        software.amazon.jsii.Kernel.call(this, "putGke", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putHttpEndpoint(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpoint value) {
        software.amazon.jsii.Kernel.call(this, "putHttpEndpoint", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putNetworkConfig(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfig value) {
        software.amazon.jsii.Kernel.call(this, "putNetworkConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCloudRunService() {
        software.amazon.jsii.Kernel.call(this, "resetCloudRunService", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetGke() {
        software.amazon.jsii.Kernel.call(this, "resetGke", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetHttpEndpoint() {
        software.amazon.jsii.Kernel.call(this, "resetHttpEndpoint", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetNetworkConfig() {
        software.amazon.jsii.Kernel.call(this, "resetNetworkConfig", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetWorkflow() {
        software.amazon.jsii.Kernel.call(this, "resetWorkflow", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getCloudFunction() {
        return software.amazon.jsii.Kernel.get(this, "cloudFunction", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunServiceOutputReference getCloudRunService() {
        return software.amazon.jsii.Kernel.get(this, "cloudRunService", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunServiceOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGkeOutputReference getGke() {
        return software.amazon.jsii.Kernel.get(this, "gke", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGkeOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpointOutputReference getHttpEndpoint() {
        return software.amazon.jsii.Kernel.get(this, "httpEndpoint", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpointOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfigOutputReference getNetworkConfig() {
        return software.amazon.jsii.Kernel.get(this, "networkConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfigOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService getCloudRunServiceInput() {
        return software.amazon.jsii.Kernel.get(this, "cloudRunServiceInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationCloudRunService.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke getGkeInput() {
        return software.amazon.jsii.Kernel.get(this, "gkeInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationGke.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpoint getHttpEndpointInput() {
        return software.amazon.jsii.Kernel.get(this, "httpEndpointInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationHttpEndpoint.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfig getNetworkConfigInput() {
        return software.amazon.jsii.Kernel.get(this, "networkConfigInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestinationNetworkConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getWorkflowInput() {
        return software.amazon.jsii.Kernel.get(this, "workflowInput", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getWorkflow() {
        return software.amazon.jsii.Kernel.get(this, "workflow", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setWorkflow(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.set(this, "workflow", java.util.Objects.requireNonNull(value, "workflow is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestination getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestination.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.eventarc_trigger.EventarcTriggerDestination value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
